@@ -48,6 +48,8 @@ SAGEMAKER_RULE_CONTAINERS_ACCOUNTS_MAP = {
     "ca-central-1": {RULES_ECR_REPO_NAME: "519511493484"},
     "cn-north-1": {RULES_ECR_REPO_NAME: "618459771430"},
     "cn-northwest-1": {RULES_ECR_REPO_NAME: "658757709296"},
+    "af-south-1": {RULES_ECR_REPO_NAME: "314341159256"},
+    "eu-south-1": {RULES_ECR_REPO_NAME: "563282790590"},
 }
 
 
