@@ -12,10 +12,13 @@
 # language governing permissions and limitations under the License.
 """Placeholder docstring"""
 from __future__ import absolute_import
+
 import logging
 
 from sagemaker.utils import get_ecr_image_uri_prefix
 
+logger = logging.getLogger(__name__)
+
 image_registry_map = {
     "us-west-1": {
         "sparkml-serving": "746614075791",
@@ -127,6 +130,16 @@ image_registry_map = {
         "scikit-learn": "451049120500",
         "xgboost": "451049120500",
     },
+    "af-south-1": {
+        "sparkml-serving": "510948584623",
+        "scikit-learn": "510948584623",
+        "xgboost": "510948584623",
+    },
+    "eu-south-1": {
+        "sparkml-serving": "978288397137",
+        "scikit-learn": "978288397137",
+        "xgboost": "978288397137",
+    },
 }
 
 
@@ -142,7 +155,7 @@ def registry(region_name, framework=None):
         account_id = image_registry_map[region_name][framework]
         return get_ecr_image_uri_prefix(account_id, region_name)
     except KeyError:
-        logging.error("The specific image or region does not exist")
+        logger.error("The specific image or region does not exist")
         raise
 
 
