@@ -34,7 +34,10 @@ This is for the source code used for the entry point with an ``Estimator``. It c
 instantiated with positional or keyword arguments.
 """
 
-EMPTY_FRAMEWORK_VERSION_WARNING = "No framework_version specified, defaulting to version {}."
+EMPTY_FRAMEWORK_VERSION_WARNING = (
+    "No framework_version specified, defaulting to version {}. "
+    "framework_version will be required in SageMaker Python SDK v2."
+)
 LATER_FRAMEWORK_VERSION_WARNING = (
     "This is not the latest supported version. "
     "If you would like to use version {latest}, "
@@ -46,12 +49,16 @@ PYTHON_2_DEPRECATION_WARNING = (
     "Please set the argument \"py_version='py3'\" to use the Python 3 {framework} image."
 )
 PARAMETER_SERVER_MULTI_GPU_WARNING = (
-    "You have selected a multi-GPU training instance type. "
-    "You have also enabled parameter server for distributed training. "
-    "Distributed training with the default parameter server configuration will not "
+    "If you have selected a multi-GPU training instance type "
+    "and also enabled parameter server for distributed training, "
+    "distributed training with the default parameter server configuration will not "
     "fully leverage all GPU cores; the parameter server will be configured to run "
     "only one worker per host regardless of the number of GPUs."
 )
+PARAMETER_V2_RENAME_WARNING = (
+    "Parameter {v1_parameter_name} will be renamed to {v2_parameter_name} "
+    "in SageMaker Python SDK v2."
+)
 
 
 EMPTY_FRAMEWORK_VERSION_ERROR = (
@@ -84,8 +91,18 @@ ASIMOV_VALID_ACCOUNTS_BY_REGION = {
     "cn-north-1": "727897471807",
     "cn-northwest-1": "727897471807",
 }
-OPT_IN_ACCOUNTS_BY_REGION = {"ap-east-1": "057415533634", "me-south-1": "724002660598"}
-ASIMOV_OPT_IN_ACCOUNTS_BY_REGION = {"ap-east-1": "871362719292", "me-south-1": "217643126080"}
+OPT_IN_ACCOUNTS_BY_REGION = {
+    "ap-east-1": "057415533634",
+    "me-south-1": "724002660598",
+    "af-south-1": "313743910680",
+    "eu-south-1": "048378556238",
+}
+ASIMOV_OPT_IN_ACCOUNTS_BY_REGION = {
+    "ap-east-1": "871362719292",
+    "me-south-1": "217643126080",
+    "af-south-1": "626614931356",
+    "eu-south-1": "692866216735",
+}
 DEFAULT_ACCOUNT = "520713654638"
 ASIMOV_PROD_ACCOUNT = "763104351884"
 ASIMOV_DEFAULT_ACCOUNT = ASIMOV_PROD_ACCOUNT
@@ -253,6 +270,11 @@ def create_image_uri(
     Returns:
         str: The appropriate image URI based on the given parameters.
     """
+    logger.warning(
+        "'create_image_uri' will be deprecated in favor of 'ImageURIProvider' class "
+        "in SageMaker Python SDK v2."
+    )
+
     optimized_families = optimized_families or []
 
     if py_version and py_version not in VALID_PY_VERSIONS:
@@ -481,6 +503,7 @@ def _list_files_to_compress(script, directory):
 def framework_name_from_image(image_name):
     # noinspection LongLine
     """Extract the framework and Python version from the image name.
+
     Args:
         image_name (str): Image URI, which should be one of the following forms:
             legacy:
@@ -491,25 +514,32 @@ def framework_name_from_image(image_name):
             '<account>.dkr.ecr.<region>.amazonaws.com/sagemaker-<fw>:<fw_version>-<device>-<py_ver>'
             current:
             '<account>.dkr.ecr.<region>.amazonaws.com/sagemaker-rl-<fw>:<rl_toolkit><rl_version>-<device>-<py_ver>'
+            current:
+            '<account>.dkr.ecr.<region>.amazonaws.com/<fw>-<image_scope>:<fw_version>-<device>-<py_ver>'
+
     Returns:
         tuple: A tuple containing:
-            str: The framework name str: The Python version str: The image tag
-            str: If the image is script mode
-        """
+
+            - str: The framework name
+            - str: The Python version
+            - str: The image tag
+            - str: If the TensorFlow image is script mode
+    """
     sagemaker_pattern = re.compile(ECR_URI_PATTERN)
     sagemaker_match = sagemaker_pattern.match(image_name)
     if sagemaker_match is None:
         return None, None, None, None
+
     # extract framework, python version and image tag
     # We must support both the legacy and current image name format.
     name_pattern = re.compile(
-        r"^(?:sagemaker(?:-rl)?-)?(tensorflow|mxnet|chainer|pytorch|scikit-learn|xgboost)(?:-)?(scriptmode|training)?:(.*)-(.*?)-(py2|py3)$"  # noqa: E501 # pylint: disable=line-too-long
+        r"""^(?:sagemaker(?:-rl)?-)?
+        (tensorflow|mxnet|chainer|pytorch|scikit-learn|xgboost)(?:-)?
+        (scriptmode|training)?
+        :(.*)-(.*?)-(py2|py3[67]?)$""",
+        re.VERBOSE,
     )
-    legacy_name_pattern = re.compile(r"^sagemaker-(tensorflow|mxnet)-(py2|py3)-(cpu|gpu):(.*)$")
-
     name_match = name_pattern.match(sagemaker_match.group(9))
-    legacy_match = legacy_name_pattern.match(sagemaker_match.group(9))
-
     if name_match is not None:
         fw, scriptmode, ver, device, py = (
             name_match.group(1),
@@ -519,6 +549,9 @@ def framework_name_from_image(image_name):
             name_match.group(5),
         )
         return fw, py, "{}-{}-{}".format(ver, device, py), scriptmode
+
+    legacy_name_pattern = re.compile(r"^sagemaker-(tensorflow|mxnet)-(py2|py3)-(cpu|gpu):(.*)$")
+    legacy_match = legacy_name_pattern.match(sagemaker_match.group(9))
     if legacy_match is not None:
         return (legacy_match.group(1), legacy_match.group(2), legacy_match.group(4), None)
     return None, None, None, None
@@ -526,13 +559,15 @@ def framework_name_from_image(image_name):
 
 def framework_version_from_tag(image_tag):
     """Extract the framework version from the image tag.
+
     Args:
         image_tag (str): Image tag, which should take the form
             '<framework_version>-<device>-<py_version>'
+
     Returns:
         str: The framework version.
     """
-    tag_pattern = re.compile("^(.*)-(cpu|gpu)-(py2|py3)$")
+    tag_pattern = re.compile("^(.*)-(cpu|gpu)-(py2|py3[67]?)$")
     tag_match = tag_pattern.match(image_tag)
     return None if tag_match is None else tag_match.group(1)
 
@@ -575,10 +610,18 @@ def empty_framework_version_warning(default_version, latest_version):
     """
     msgs = [EMPTY_FRAMEWORK_VERSION_WARNING.format(default_version)]
     if default_version != latest_version:
-        msgs.append(LATER_FRAMEWORK_VERSION_WARNING.format(latest=latest_version))
+        msgs.append(later_framework_version_warning(latest_version))
     return " ".join(msgs)
 
 
+def later_framework_version_warning(latest_version):
+    """
+    Args:
+        latest_version:
+    """
+    return LATER_FRAMEWORK_VERSION_WARNING.format(latest=latest_version)
+
+
 def warn_if_parameter_server_with_multi_gpu(training_instance_type, distributions):
     """Warn the user that training will not fully leverage all the GPU
     cores if parameter server is enabled and a multi-GPU instance is selected.
@@ -605,9 +648,9 @@ def warn_if_parameter_server_with_multi_gpu(training_instance_type, distribution
         return
 
     is_multi_gpu_instance = (
-        training_instance_type.split(".")[1].startswith("p")
-        and training_instance_type not in SINGLE_GPU_INSTANCE_TYPES
-    )
+        training_instance_type == "local_gpu"
+        or training_instance_type.split(".")[1].startswith("p")
+    ) and training_instance_type not in SINGLE_GPU_INSTANCE_TYPES
 
     ps_enabled = "parameter_server" in distributions and distributions["parameter_server"].get(
         "enabled", False
@@ -647,6 +690,17 @@ def python_deprecation_warning(framework, latest_supported_version):
     )
 
 
+def parameter_v2_rename_warning(v1_parameter_name, v2_parameter_name):
+    """
+    Args:
+        v1_parameter_name: parameter name used in SageMaker Python SDK v1
+        v2_parameter_name: parameter name used in SageMaker Python SDK v2
+    """
+    return PARAMETER_V2_RENAME_WARNING.format(
+        v1_parameter_name=v1_parameter_name, v2_parameter_name=v2_parameter_name
+    )
+
+
 def _region_supports_debugger(region_name):
     """Returns boolean indicating whether the region supports Amazon SageMaker Debugger.
 
