@@ -327,7 +327,7 @@ class LocalSagemakerRuntimeClient(object):
         try:
             import urllib3
         except ImportError as e:
-            logging.error(_module_import_error("urllib3", "Local mode", "local"))
+            logger.error(_module_import_error("urllib3", "Local mode", "local"))
             raise e
 
         self.http = urllib3.PoolManager()
@@ -343,6 +343,7 @@ class LocalSagemakerRuntimeClient(object):
         Accept=None,
         CustomAttributes=None,
         TargetModel=None,
+        TargetVariant=None,
     ):
         """
 
@@ -370,6 +371,9 @@ class LocalSagemakerRuntimeClient(object):
         if TargetModel is not None:
             headers["X-Amzn-SageMaker-Target-Model"] = TargetModel
 
+        if TargetVariant is not None:
+            headers["X-Amzn-SageMaker-Target-Variant"] = TargetVariant
+
         r = self.http.request("POST", url, body=Body, preload_content=False, headers=headers)
 
         return {"Body": r, "ContentType": Accept}
@@ -419,7 +423,7 @@ class LocalSession(Session):
             try:
                 import yaml
             except ImportError as e:
-                logging.error(_module_import_error("yaml", "Local mode", "local"))
+                logger.error(_module_import_error("yaml", "Local mode", "local"))
                 raise e
 
             self.config = yaml.load(open(sagemaker_config_file, "r"))
