@@ -100,8 +100,8 @@ class RLEstimator(Framework):
         Args:
             entry_point (str): Path (absolute or relative) to the Python source
                 file which should be executed as the entry point to training.
-                This should be compatible with Python 3.5 for MXNet or Python
-                3.6 for TensorFlow.
+                If ``source_dir`` is specified, then ``entry_point``
+                must point to a file located at the root of ``source_dir``.
             toolkit (sagemaker.rl.RLToolkit): RL toolkit you want to use for
                 executing your model training code.
             toolkit_version (str): RL toolkit version you want to be use for
@@ -187,8 +187,8 @@ class RLEstimator(Framework):
 
             entry_point (str): Path (absolute or relative) to the Python source
                 file which should be executed as the entry point for MXNet
-                hosting. This should be compatible with Python 3.5 (default:
-                self.entry_point)
+                hosting (default: self.entry_point). If ``source_dir`` is specified,
+                then ``entry_point`` must point to a file located at the root of ``source_dir``.
             source_dir (str): Path (absolute or relative) to a directory with
                 any other training source code dependencies aside from the entry
                 point file (default: self.source_dir). Structure within this
@@ -199,6 +199,7 @@ class RLEstimator(Framework):
                 folders will be copied to SageMaker in the same folder where the
                 entry_point is copied. If the ```source_dir``` points to S3,
                 code will be uploaded and the S3 location will be used instead.
+                This is not supported with "local code" in Local Mode.
             **kwargs: Additional kwargs passed to the :class:`~sagemaker.model.FrameworkModel`
                 constructor.
 
@@ -362,10 +363,10 @@ class RLEstimator(Framework):
         Args:
             framework:
         """
-        if framework and framework not in RLFramework:
+        if framework and framework not in list(RLFramework):
             raise ValueError(
-                "Invalid type: {}, valid RL frameworks types are: [{}]".format(
-                    framework, [t for t in RLFramework]
+                "Invalid type: {}, valid RL frameworks types are: {}".format(
+                    framework, list(RLFramework)
                 )
             )
 
@@ -375,11 +376,9 @@ class RLEstimator(Framework):
         Args:
             toolkit:
         """
-        if toolkit and toolkit not in RLToolkit:
+        if toolkit and toolkit not in list(RLToolkit):
             raise ValueError(
-                "Invalid type: {}, valid RL toolkits types are: [{}]".format(
-                    toolkit, [t for t in RLToolkit]
-                )
+                "Invalid type: {}, valid RL toolkits types are: {}".format(toolkit, list(RLToolkit))
             )
 
     @classmethod
