@@ -15,8 +15,6 @@ from __future__ import absolute_import
 
 import logging
 
-from sagemaker import fw_utils
-
 import sagemaker
 from sagemaker.fw_utils import model_code_key_prefix, python_deprecation_warning
 from sagemaker.fw_registry import default_framework_uri
@@ -81,12 +79,12 @@ class SKLearnModel(FrameworkModel):
                 might use the IAM role, if it needs to access an AWS resource.
             entry_point (str): Path (absolute or relative) to the Python source
                 file which should be executed as the entry point to model
-                hosting. This should be compatible with either Python 2.7 or
-                Python 3.5.
+                hosting. If ``source_dir`` is specified, then ``entry_point``
+                must point to a file located at the root of ``source_dir``.
             image (str): A Docker image URI (default: None). If not specified, a
                 default image for Scikit-learn will be used.
             py_version (str): Python version you want to use for executing your
-                model training code (default: 'py2').
+                model training code (default: 'py3').
             framework_version (str): Scikit-learn version you want to use for
                 executing your model training code.
             predictor_cls (callable[str, sagemaker.session.Session]): A function
@@ -118,16 +116,16 @@ class SKLearnModel(FrameworkModel):
         self.framework_version = framework_version
         self.model_server_workers = model_server_workers
 
-    def prepare_container_def(self, instance_type, accelerator_type=None):
+    def prepare_container_def(self, instance_type=None, accelerator_type=None):
         """Return a container definition with framework configuration set in
         model environment variables.
 
         Args:
             instance_type (str): The EC2 instance type to deploy this Model to.
-                For example, 'ml.p2.xlarge'.
+                This parameter is unused because Scikit-learn supports only CPU.
             accelerator_type (str): The Elastic Inference accelerator type to
                 deploy to the instance for loading and making inferences to the
-                model. For example, 'ml.eia1.medium'. Note: accelerator types
+                model. This parameter is unused because accelerator types
                 are not supported by SKLearnModel.
 
         Returns:
@@ -139,9 +137,8 @@ class SKLearnModel(FrameworkModel):
 
         deploy_image = self.image
         if not deploy_image:
-            image_tag = "{}-{}-{}".format(self.framework_version, "cpu", self.py_version)
-            deploy_image = default_framework_uri(
-                self.__framework_name__, self.sagemaker_session.boto_region_name, image_tag
+            deploy_image = self.serving_image_uri(
+                self.sagemaker_session.boto_region_name, instance_type
             )
 
         deploy_key_prefix = model_code_key_prefix(self.key_prefix, self.name, deploy_image)
@@ -156,22 +153,17 @@ class SKLearnModel(FrameworkModel):
         )
         return sagemaker.container_def(deploy_image, model_data_uri, deploy_env)
 
-    def serving_image_uri(self, region_name, instance_type):
+    def serving_image_uri(self, region_name, instance_type):  # pylint: disable=unused-argument
         """Create a URI for the serving image.
 
         Args:
             region_name (str): AWS region where the image is uploaded.
-            instance_type (str): SageMaker instance type. Used to determine device type
-                (cpu/gpu/family-specific optimized).
+            instance_type (str): SageMaker instance type. This parameter is unused because
+                Scikit-learn supports only CPU.
 
         Returns:
             str: The appropriate image URI based on the given parameters.
 
         """
-        return fw_utils.create_image_uri(
-            region_name,
-            self.__framework_name__,
-            instance_type,
-            self.framework_version,
-            self.py_version,
-        )
+        image_tag = "{}-{}-{}".format(self.framework_version, "cpu", self.py_version)
+        return default_framework_uri(self.__framework_name__, region_name, image_tag)
