@@ -237,9 +237,7 @@ class TensorFlow(Framework):
             py_version (str): Python version you want to use for executing your model training
                 code (default: 'py2').
             framework_version (str): TensorFlow version you want to use for executing your model
-                training code. List of supported versions
-                https://github.com/aws/sagemaker-python-sdk#tensorflow-sagemaker-estimators.
-                If not specified, this will default to 1.11.
+                training code. If not specified, this will default to 1.11.
             model_dir (str): S3 location where the checkpoint data and models can be exported to
                 during training (default: None). It will be passed in the training script as one of
                 the command line arguments. If not specified, one is provided based on
@@ -311,6 +309,7 @@ class TensorFlow(Framework):
             )
 
         if distributions is not None:
+            logger.warning(fw.parameter_v2_rename_warning("distribution", distributions))
             train_instance_type = kwargs.get("train_instance_type")
             fw.warn_if_parameter_server_with_multi_gpu(
                 training_instance_type=train_instance_type, distributions=distributions
@@ -385,7 +384,9 @@ class TensorFlow(Framework):
 
         if (not self._script_mode_enabled()) and self._only_script_mode_supported():
             logger.warning(
-                "Legacy mode is deprecated in versions 1.13 and higher. Using script mode instead."
+                "Legacy mode is deprecated in versions 1.13 and higher. Using script mode instead. "
+                "Legacy mode and its training parameters will be deprecated in "
+                "SageMaker Python SDK v2. Please use TF 1.13 or higher and script mode."
             )
             self.script_mode = True
 
@@ -555,19 +556,22 @@ class TensorFlow(Framework):
             model_server_workers (int): Optional. The number of worker processes used by the
                 inference server. If None, server will use one worker per vCPU.
             vpc_config_override (dict[str, list[str]]): Optional override for VpcConfig set on the
-                model.
-                Default: use subnets and security groups from this Estimator.
+                model. Default: use subnets and security groups from this Estimator.
+
                 * 'Subnets' (list[str]): List of subnet ids.
                 * 'SecurityGroupIds' (list[str]): List of security group ids.
+
             endpoint_type (str): Optional. Selects the software stack used by the inference server.
                 If  not specified, the model will be configured to use the default
                 SageMaker model server. If 'tensorflow-serving', the model will be configured to
                 use the SageMaker Tensorflow Serving container.
             entry_point (str): Path (absolute or relative) to the local Python source file which
-                should be executed as the entry point to training. If not specified and
-                ``endpoint_type`` is 'tensorflow-serving', no entry point is used. If
-                ``endpoint_type`` is also ``None``, then the training entry point is used.
-            source_dir (str): Path (absolute or relative or an S3 URI ) to a directory with any
+                should be executed as the entry point to training. If ``source_dir`` is specified,
+                then ``entry_point`` must point to a file located at the root of ``source_dir``.
+                If not specified and ``endpoint_type`` is 'tensorflow-serving',
+                no entry point is used. If ``endpoint_type`` is also ``None``,
+                then the training entry point is used.
+            source_dir (str): Path (absolute or relative or an S3 URI) to a directory with any
                 other serving source code dependencies aside from the entry point file. If
                 ``source_dir`` is an S3 URI, it must point to a tar.gz file. If not specified
                 and ``endpoint_type`` is 'tensorflow-serving', no source_dir is used. If
@@ -578,6 +582,7 @@ class TensorFlow(Framework):
                 If not specified and ``endpoint_type`` is 'tensorflow-serving', ``dependencies`` is
                 set to ``None``.
                 If ``endpoint_type`` is also ``None``, then the dependencies from training are used.
+                This is not supported with "local code" in Local Mode.
             **kwargs: Additional kwargs passed to :class:`~sagemaker.tensorflow.serving.Model`
                 and :class:`~sagemaker.tensorflow.model.TensorFlowModel` constructors.
 
@@ -723,7 +728,7 @@ class TensorFlow(Framework):
 
     def _script_mode_enabled(self):
         """Placeholder docstring"""
-        return self.py_version == "py3" or self.script_mode
+        return self.py_version.startswith("py3") or self.script_mode
 
     def _validate_and_set_debugger_configs(self):
         """
@@ -825,9 +830,11 @@ class TensorFlow(Framework):
                 If 'tensorflow-serving', the model will be configured to
                 use the SageMaker Tensorflow Serving container.
             entry_point (str): Path (absolute or relative) to the local Python source file which
-                should be executed as the entry point to training. If not specified and
-                ``endpoint_type`` is 'tensorflow-serving', no entry point is used. If
-                ``endpoint_type`` is also ``None``, then the training entry point is used.
+                should be executed as the entry point to training. If ``source_dir`` is specified,
+                then ``entry_point`` must point to a file located at the root of ``source_dir``.
+                If not specified and ``endpoint_type`` is 'tensorflow-serving',
+                no entry point is used. If ``endpoint_type`` is also ``None``,
+                then the training entry point is used.
             vpc_config_override (dict[str, list[str]]): Optional override for
                 the VpcConfig set on the model.
                 Default: use subnets and security groups from this Estimator.
@@ -849,7 +856,7 @@ class TensorFlow(Framework):
         role = role or self.role
 
         if self.latest_training_job is None:
-            logging.warning(
+            logger.warning(
                 "No finished training job found associated with this estimator. Please make sure "
                 "this estimator is only used for building workflow config"
             )
