@@ -82,8 +82,8 @@ class TensorFlowModel(FrameworkModel):
                 might use the IAM role, if it needs to access an AWS resource.
             entry_point (str): Path (absolute or relative) to the Python source
                 file which should be executed as the entry point to model
-                hosting. This should be compatible with either Python 2.7 or
-                Python 3.5.
+                hosting. If ``source_dir`` is specified, then ``entry_point``
+                must point to a file located at the root of ``source_dir``.
             image (str): A Docker image URI (default: None). If not specified, a
                 default image for TensorFlow will be used.
             py_version (str): Python version you want to use for executing your
@@ -124,7 +124,7 @@ class TensorFlowModel(FrameworkModel):
         self.framework_version = framework_version or defaults.TF_VERSION
         self.model_server_workers = model_server_workers
 
-    def prepare_container_def(self, instance_type, accelerator_type=None):
+    def prepare_container_def(self, instance_type=None, accelerator_type=None):
         """Return a container definition with framework configuration set in
         model environment variables.
 
@@ -143,6 +143,11 @@ class TensorFlowModel(FrameworkModel):
         """
         deploy_image = self.image
         if not deploy_image:
+            if instance_type is None:
+                raise ValueError(
+                    "Must supply either an instance type (for choosing CPU vs GPU) or an image URI."
+                )
+
             region_name = self.sagemaker_session.boto_region_name
             deploy_image = self.serving_image_uri(
                 region_name, instance_type, accelerator_type=accelerator_type
