@@ -54,6 +54,8 @@ HYPERPARAMETER_TUNING_JOB_NAME = "HyperParameterTuningJobName"
 PARENT_HYPERPARAMETER_TUNING_JOBS = "ParentHyperParameterTuningJobs"
 WARM_START_TYPE = "WarmStartType"
 
+logger = logging.getLogger(__name__)
+
 
 class WarmStartTypes(Enum):
     """Warm Start Configuration type. There can be two types of warm start jobs:
@@ -92,10 +94,10 @@ class WarmStartConfig(object):
                 warm start the new tuning job.
         """
 
-        if warm_start_type not in WarmStartTypes:
+        if warm_start_type not in list(WarmStartTypes):
             raise ValueError(
-                "Invalid type: {}, valid warm start types are: [{}]".format(
-                    warm_start_type, [t for t in WarmStartTypes]
+                "Invalid type: {}, valid warm start types are: {}".format(
+                    warm_start_type, list(WarmStartTypes)
                 )
             )
 
@@ -750,6 +752,10 @@ class HyperparameterTuner(object):
         self._ensure_last_tuning_job()
         self.latest_tuning_job.stop()
 
+    def describe(self):
+        """Returns a response from the DescribeHyperParameterTuningJob API call."""
+        return self.sagemaker_session.describe_tuning_job(self._current_job_name)
+
     def wait(self):
         """Wait for latest hyperparameter tuning job to finish."""
         self._ensure_last_tuning_job()
@@ -836,6 +842,11 @@ class HyperparameterTuner(object):
         Args:
             endpoint_name (str): Name of the endpoint to delete
         """
+        logger.warning(
+            "HyperparameterTuner.delete_endpoint() will be deprecated in SageMaker Python SDK v2. "
+            "Please use the delete_endpoint() function on your predictor instead."
+        )
+
         endpoint_name = endpoint_name or self.best_training_job()
         self.sagemaker_session.delete_endpoint(endpoint_name)
 
@@ -1450,7 +1461,7 @@ class _TuningJob(_Job):
             information about the started job.
         """
 
-        logging.info("_TuningJob.start_new!!!")
+        logger.info("_TuningJob.start_new!!!")
 
         warm_start_config_req = None
         if tuner.warm_start_config:
@@ -1520,7 +1531,7 @@ class _TuningJob(_Job):
 
         if isinstance(inputs, s3_input):
             if "InputMode" in inputs.config:
-                logging.debug(
+                logger.debug(
                     "Selecting s3_input's input_mode (%s) for TrainingInputMode.",
                     inputs.config["InputMode"],
                 )
