@@ -15,8 +15,6 @@ from __future__ import absolute_import
 
 import logging
 
-from sagemaker import fw_utils
-
 import sagemaker
 from sagemaker.fw_utils import model_code_key_prefix
 from sagemaker.fw_registry import default_framework_uri
@@ -74,8 +72,8 @@ class XGBoostModel(FrameworkModel):
                 training data and model artifacts. After the endpoint is created, the inference
                 code might use the IAM role, if it needs to access an AWS resource.
             entry_point (str): Path (absolute or relative) to the Python source file which should
-                be executed  as the entry point to model hosting.
-                This should be compatible with either Python 2.7 or Python 3.5.
+                be executed  as the entry point to model hosting. If ``source_dir`` is specified,
+                then ``entry_point`` must point to a file located at the root of ``source_dir``.
             image (str): A Docker image URI (default: None). If not specified, a default image for
                 XGBoos will be used.
             py_version (str): Python version you want to use for executing your model training code
@@ -107,26 +105,24 @@ class XGBoostModel(FrameworkModel):
         self.framework_version = framework_version
         self.model_server_workers = model_server_workers
 
-    def prepare_container_def(self, instance_type, accelerator_type=None):
+    def prepare_container_def(self, instance_type=None, accelerator_type=None):
         """Return a container definition with framework configuration
         set in model environment variables.
 
         Args:
-            instance_type (str): The EC2 instance type to deploy this Model to. For example,
-                'ml.m5.xlarge'.
+            instance_type (str): The EC2 instance type to deploy this Model to.
+                This parameter is unused because XGBoost supports only CPU.
             accelerator_type (str): The Elastic Inference accelerator type to deploy to the
-            instance for loading and making inferences to the model. For example,
-                'ml.eia1.medium'.
-            Note: accelerator types are not supported by XGBoostModel.
+            instance for loading and making inferences to the model. This parameter is
+                unused because accelerator types are not supported by XGBoostModel.
 
         Returns:
             dict[str, str]: A container definition object usable with the CreateModel API.
         """
         deploy_image = self.image
         if not deploy_image:
-            image_tag = "{}-{}-{}".format(self.framework_version, "cpu", self.py_version)
-            deploy_image = default_framework_uri(
-                self.__framework_name__, self.sagemaker_session.boto_region_name, image_tag
+            deploy_image = self.serving_image_uri(
+                self.sagemaker_session.boto_region_name, instance_type
             )
 
         deploy_key_prefix = model_code_key_prefix(self.key_prefix, self.name, deploy_image)
@@ -138,22 +134,17 @@ class XGBoostModel(FrameworkModel):
             deploy_env[MODEL_SERVER_WORKERS_PARAM_NAME.upper()] = str(self.model_server_workers)
         return sagemaker.container_def(deploy_image, self.model_data, deploy_env)
 
-    def serving_image_uri(self, region_name, instance_type):
+    def serving_image_uri(self, region_name, instance_type):  # pylint: disable=unused-argument
         """Create a URI for the serving image.
 
         Args:
             region_name (str): AWS region where the image is uploaded.
-            instance_type (str): SageMaker instance type. Used to determine device type
-                (cpu/gpu/family-specific optimized).
+            instance_type (str): SageMaker instance type. This parameter is unused because
+                XGBoost supports only CPU.
 
         Returns:
             str: The appropriate image URI based on the given parameters.
 
         """
-        return fw_utils.create_image_uri(
-            region_name,
-            self.__framework_name__,
-            instance_type,
-            self.framework_version,
-            self.py_version,
-        )
+        image_tag = "{}-{}-{}".format(self.framework_version, "cpu", self.py_version)
+        return default_framework_uri(self.__framework_name__, region_name, image_tag)
